@@ -121,6 +121,13 @@ $Template::Stash::LIST_OPS->{ containsany } =
       return 0;
   };
 
+# Allow us to still get the scalar if we use the list operation ".0" on it,
+# as we often do for defaults in query.cgi and other places.
+$Template::Stash::SCALAR_OPS->{ 0 } = 
+  sub {
+      return $_[0];
+  };
+
 # Add a "substr" method to the Template Toolkit's "scalar" object
 # that returns a substring of a string.
 $Template::Stash::SCALAR_OPS->{ substr } = 
@@ -187,6 +194,7 @@ sub create {
                 $var =~ s/([\\\'\"])/\\$1/g;
                 $var =~ s/\n/\\n/g;
                 $var =~ s/\r/\\r/g;
+                $var =~ s/\@/\\x40/g; # anti-spam for email addresses
                 return $var;
             },
 
@@ -211,6 +219,10 @@ sub create {
             # a full URL that may have characters that need encoding.
             url_quote => \&Bugzilla::Util::url_quote ,
 
+            # This filter is similar to url_quote but used a \ instead of a %
+            # as prefix. In addition it replaces a ' ' by a '_'.
+            css_class_quote => \&Bugzilla::Util::css_class_quote ,
+
             quoteUrls => \&::quoteUrls ,
 
             bug_link => [ sub {
@@ -237,6 +249,19 @@ sub create {
 
             # Format a time for display (more info in Bugzilla::Util)
             time => \&Bugzilla::Util::format_time,
+
+            # Override html filter to obscure the '@' in user visible strings
+            # See bug 120030 for details
+            html => sub {
+                my ($var) = Template::Filters::html_filter(@_);
+                $var =~ s/\@/\&#64;/g;
+                return $var;
+            },
+            
+            # We force filtering of every variable in key security-critical
+            # places; we have a none filter for people to use when they 
+            # really, really don't want a variable to be changed.
+            none => sub { return $_[0]; } ,
         },
 
         PLUGIN_BASE => 'Bugzilla::Template::Plugin',
@@ -249,14 +274,13 @@ sub create {
             # Function to create date strings
             'time2str' => \&Date::Format::time2str,
 
-            # Function for processing global parameters that contain references
-            # to other global parameters.
-            'PerformSubsts' => \&::PerformSubsts ,
-
             # Generic linear search function
             'lsearch' => \&Bugzilla::Util::lsearch,
 
-            # UserInGroup - you probably want to cache this
+            # Currently logged in user, if any
+            'user' => sub { return Bugzilla->user; },
+
+            # UserInGroup. Deprecated - use the user.* functions instead
             'UserInGroup' => \&::UserInGroup,
 
             # SendBugMail - sends mail about a bug, using Bugzilla::BugMail.pm
@@ -265,10 +289,6 @@ sub create {
                 require Bugzilla::BugMail;
                 Bugzilla::BugMail::Send($id, $mailrecipients);
             },
- 
-            # SyncAnyPendingShadowChanges
-            # - called in the footer to sync the shadowdb
-            'SyncAnyPendingShadowChanges' => \&::SyncAnyPendingShadowChanges,
 
             # Bugzilla version
             # This could be made a ref, or even a CONSTANT with TT2.08
