@@ -47,7 +47,7 @@ function do_shift(l) {
 
 function go_to (url) {
     if ( typeof sidebar != "undefined" && sidebar == 1 ) {
-        load_relative_url(url);
+        load_absolute_url(url);
     } else {
         document.location.href = url;
     }
@@ -706,7 +706,7 @@ function QuickSearch (input)
     if (input == "") 
     {
         //once this _is_ on http://bugzilla.mozilla.org, it should just return;
-        go_to("/bugzilla");
+        go_to(bugzilla);
     } 
     else if (input.match(/^[0-9, ]*$/)) 
     {
