@@ -33,17 +33,7 @@
 # Safe vmethods                   - [% foo.size %]
 # TT loop variables               - [% loop.count %]
 # Already-filtered stuff          - [% wibble FILTER html %]
-#   where the filter is one of html|csv|js|url_quote|quoteUrls|time|uri|xml
-
-# Key:
-#
-# "#": directive should be filtered, but not doing so is not a security hole
-# The plan is to come back and add filtering for all those marked "#" after
-# the security release.
-#
-# "# Email": as above; but noting that it's an email address.
-# Other sorts of comments denote cleanups noticed while doing this work;
-# they should be fixed in the very short term.
+#   where the filter is one of html|csv|js|url_quote|quoteUrls|time|uri|xml|none
 
 %::safe = (
 
@@ -80,19 +70,15 @@
   'field.accesskey',
   'sel.name',
   'sel.accesskey',
-  'button_name', #
 ],
 
-'search/knob.html.tmpl' => [
-  'button_name', #
+'search/search-specific.html.tmpl' => [
+  's',
 ],
 
-'search/search-report-graph.html.tmpl' => [
-  'button_name', #
-],
-
-'search/search-report-table.html.tmpl' => [
-  'button_name', #
+'search/tabs.html.tmpl' => [
+  'tab.name',
+  'tab.description',
 ],
 
 'request/queue.html.tmpl' => [
@@ -105,32 +91,20 @@
 
 'reports/components.html.tmpl' => [
   'numcols',
-  'numcols - 1',
   'comp.description', 
-  'comp.initialowner', # email address
-  'comp.initialqacontact', # email address
-],
-
-'reports/duplicates-simple.html.tmpl' => [
-  'title', #
 ],
 
 'reports/duplicates-table.html.tmpl' => [
-  '"&maxrows=$maxrows" IF maxrows',
-  '"&changedsince=$changedsince" IF changedsince',
-  '"&product=$product" IF product', #
-  '"&format=$format" IF format', #
-  '"&bug_id=$bug_ids_string&sortvisible=1" IF sortvisible',
+  '"&amp;maxrows=$maxrows" IF maxrows',
+  '"&amp;changedsince=$changedsince" IF changedsince',
+  '"&amp;bug_id=$bug_ids_string&amp;sortvisible=1" 
+                                                            IF sortvisible',
   'column.name', 
   'column.description',
   'vis_bug_ids.push(bug.id)', 
   'bug.id', 
   'bug.count', 
   'bug.delta', 
-  'bug.component', #
-  'bug.bug_severity', #
-  'bug.op_sys', #
-  'bug.target_milestone', #
 ],
 
 'reports/duplicates.html.tmpl' => [
@@ -146,11 +120,9 @@
 ],
 
 'reports/report-table.csv.tmpl' => [
-  '"$tbl_field_disp: $tbl\n" IF tbl_field', #
-  'row_field_disp IF row_field', #
-  'col_field_disp', #
   'num_bugs',
   'data.$tbl.$col.$row',
+  'title',
   '', # This is not a bug in the filter exceptions - this template has an 
       # empty directive which is necessary for it to work properly.
 ],
@@ -160,7 +132,6 @@
   '"&amp;$tbl_vals" IF tbl_vals', 
   '"&amp;$col_vals" IF col_vals', 
   '"&amp;$row_vals" IF row_vals', 
-  'tbl_disp', # 
   'classes.$row_idx.$col_idx', 
   'urlbase', 
   'data.$tbl.$col.$row', 
@@ -170,21 +141,13 @@
 ],
 
 'reports/report.html.tmpl' => [
-  'tbl_field_disp IF tbl_field', #
-  'row_field_disp IF row_field', #
-  'col_field_disp', #
   'imagebase', 
   'width', 
   'height', 
   'imageurl', 
   'formaturl', 
   'other_format.name', 
-  'other_format.description', #
   'sizeurl', 
-  'height + 100', 
-  'height - 100', 
-  'width + 100', 
-  'width - 100', 
   'switchbase',
   'format',
   'cumulate',
@@ -197,9 +160,38 @@
   'bug.delta', 
 ],
 
+'reports/chart.html.tmpl' => [
+  'width', 
+  'height', 
+  'imageurl', 
+  'sizeurl', 
+  'height + 100', 
+  'height - 100', 
+  'width + 100', 
+  'width - 100', 
+],
+
+'reports/series-common.html.tmpl' => [
+  'sel.name', 
+  'sel.accesskey', 
+  '"onchange=\'$sel.onchange\'" IF sel.onchange', 
+],
+
+'reports/chart.csv.tmpl' => [
+  'data.$j.$i', 
+],
+
+'reports/create-chart.html.tmpl' => [
+  'series.series_id', 
+  'newidx',
+],
+
+'reports/edit-series.html.tmpl' => [
+  'default.series_id', 
+],
+
 'list/change-columns.html.tmpl' => [
   'column', 
-  'field_descs.${column} || column', #
 ],
 
 'list/edit-multiple.html.tmpl' => [
@@ -216,7 +208,6 @@
 
 'list/list.html.tmpl' => [
   'buglist', 
-  'bugowners', # email address
 ],
 
 'list/list.rdf.tmpl' => [
@@ -226,13 +217,9 @@
 ],
 
 'list/table.html.tmpl' => [
-  'id', 
-  'splitheader ? 2 : 1', 
-  'abbrev.$id.title || field_descs.$id || column.title', #
   'tableheader',
-  'bug.bug_severity', #
-  'bug.priority', #
   'bug.bug_id', 
+  'abbrev.$id.title || field_descs.$id || column.title',
 ],
 
 'list/list.csv.tmpl' => [
@@ -257,19 +244,12 @@
   'proddesc.$p', 
 ],
 
+# You are not permitted to add any values here. Everything in this file should 
+# be filtered unless there's an extremely good reason why not, in which case,
+# use the "none" dummy filter.
 'global/code-error.html.tmpl' => [
-  'parameters', 
-  'bug.bug_id',
-  'field', 
-  'argument', #
-  'function', #
-  'bug_id', # Need to remove unused error no_bug_data
-  'variables.id', 
-  'template_error_msg', # Should move filtering from CGI.pl to template
-  'error', 
-  'error_message', 
 ],
-
+ 
 'global/header.html.tmpl' => [
   'javascript', 
   'style', 
@@ -281,54 +261,29 @@
   'h3', 
   'message', 
 ],
-'global/hidden-fields.html.tmpl' => [
-  'mvalue | html | html_linebreak', # Need to eliminate | usage
-  'field.value | html | html_linebreak',
-],
 
 'global/messages.html.tmpl' => [
-  'parameters',
-  '# ---', # Work out what this is
-  'namedcmd', #
-  'old_email', # email address
-  'new_email', # email address
   'message_tag', 
+  'series.frequency * 2',
 ],
 
 'global/select-menu.html.tmpl' => [
   'options', 
-  'onchange', # Again, need to be certain where we are filtering
   'size', 
 ],
 
 'global/useful-links.html.tmpl' => [
   'email', 
-  'user.login', # Email address
 ],
 
-# Need to change this and code-error to use a no-op filter, for safety
+# You are not permitted to add any values here. Everything in this file should 
+# be filtered unless there's an extremely good reason why not, in which case,
+# use the "none" dummy filter.
 'global/user-error.html.tmpl' => [
-  'disabled_reason', 
-  'bug_link', 
-  'action', # 
-  'bug_id', 
-  'both', 
-  'filesize', 
-  'attach_id', 
-  'field', 
-  'field_descs.$field', 
-  'today', 
-  'product', #
-  'max', 
-  'votes', 
-  'error_message', 
 ],
 
 'global/confirm-user-match.html.tmpl' => [
-  '# use the global field descs', # Need to fix commenting style here
   'script',
-  '# this is messy to allow later expansion',
-  '# ELSIF for things that don\'t belong in the field_descs hash here',
   'fields.${field_name}.flag_type.name',
 ],
 
@@ -339,7 +294,6 @@
   'bug_list.last', 
   'bug.bug_id', 
   'bug.votes', 
-  'PerformSubsts(Param(\'mybugstemplate\'), substs)', 
 ],
 
 'bug/comments.html.tmpl' => [
@@ -355,25 +309,16 @@
 ],
 
 'bug/dependency-tree.html.tmpl' => [
-  'hide_resolved ? "Open b" : "B"', 
   'bugid', 
   'maxdepth', 
   'dependson_ids.join(",")', 
   'blocked_ids.join(",")', 
   'dep_id', 
-  'hide_resolved ? 0 : 1', 
-  'hide_resolved ? "Show" : "Hide"', 
-  'realdepth < 2 || maxdepth == 1 ? "disabled" : ""', 
   'hide_resolved', 
-  'realdepth < 2 ? "disabled" : ""', 
   'maxdepth + 1', 
-  'maxdepth == 0 || maxdepth == realdepth ? "disabled" : ""', 
-  'realdepth < 2 || ( maxdepth && maxdepth < 2 ) ? "disabled" : ""',
   'maxdepth > 0 && maxdepth <= realdepth ? maxdepth : ""',
-  'maxdepth == 1 ? 1 
+  'maxdepth == 1 ? 1
                        : ( maxdepth ? maxdepth - 1 : realdepth - 1 )',
-  'realdepth < 2 || ! maxdepth || maxdepth >= realdepth ?
-            "disabled" : ""',
 ],
 
 'bug/edit.html.tmpl' => [
@@ -383,18 +328,21 @@
   'bug.votes', 
   'group.bit', 
   'group.description', 
-  'knum', 
   'dep.title', 
   'dep.fieldname', 
   'accesskey', 
   'bug.${dep.fieldname}.join(\', \')', 
   'selname',
   'depbug FILTER bug_link(depbug)',
-  '"bug ${bug.dup_id}" FILTER bug_link(bug.dup_id)',
+  '"${bug.dup_id}" FILTER bug_link(bug.dup_id)',
+],
+
+'bug/knob.html.tmpl' => [
+  'bug.bug_id', 
+  'knum', 
 ],
 
 'bug/navigate.html.tmpl' => [
-  'this_bug_idx + 1', 
   'bug_list.first', 
   'bug_list.last', 
   'bug_list.$prev_bug', 
@@ -403,8 +351,6 @@
 
 'bug/show-multiple.html.tmpl' => [
   'bug.bug_id', 
-  'bug.component', #
-  'attr.description', #
 ],
 
 'bug/show.xml.tmpl' => [
@@ -432,7 +378,6 @@
   'product.total', 
   'product.maxvotes', 
 ],
-# h2 = voting_user.name # Email
 
 'bug/process/confirm-duplicate.html.tmpl' => [
   'original_bug_id', 
@@ -452,21 +397,11 @@
   'id', 
 ],
 
-'bug/process/verify-new-product.html.tmpl' => [
-  'form.product', # 
-],
-
-'bug/process/bugmail.html.tmpl' => [
-  'description', 
-  'name', # Email 
-],
-
 'bug/create/comment.txt.tmpl' => [
   'form.comment', 
 ],
 
 'bug/create/create.html.tmpl' => [
-  'default.bug_status', #
   'g.bit',
   'g.description',
   'sel.name',
@@ -476,7 +411,6 @@
 'bug/create/create-guided.html.tmpl' => [
   'matches.0', 
   'tablecolour',
-  'product', #
   'buildid',
   'sel', 
 ],
@@ -486,7 +420,6 @@
 ],
 
 'bug/activity/table.html.tmpl' => [
-  'operation.who', # Email
   'change.attachid', 
   'change.field', 
 ],
@@ -510,11 +443,7 @@
 
 'attachment/list.html.tmpl' => [
   'attachment.attachid', 
-  'FOR flag = attachment.flags', # Bug? No FOR directive
-  'flag.type.name', 
   'flag.status',
-  'flag.requestee.nick', # Email
-  'show_attachment_flags ? 4 : 3',
   'bugid',
 ],
 
@@ -527,6 +456,27 @@
   'bugid', 
 ],
 
+'attachment/diff-header.html.tmpl' => [
+  'attachid',
+  'bugid',
+  'old_url',
+  'new_url',
+  'oldid',
+  'newid',
+  'style',
+  'javascript',
+  'patch.id',
+],
+
+'attachment/diff-file.html.tmpl' => [
+  'lxr_prefix',
+  'file.minus_lines',
+  'file.plus_lines',
+  'bonsai_prefix',
+  'section.old_start',
+  'section_num'
+],
+
 'admin/products/groupcontrol/confirm-edit.html.tmpl' => [
   'group.count', 
 ],
@@ -543,7 +493,6 @@
 
 'admin/flag-type/confirm-delete.html.tmpl' => [
   'flag_count', 
-  'name', #
   'flag_type.id', 
 ],
 
@@ -551,14 +500,12 @@
   'action', 
   'type.id', 
   'type.target_type', 
-  'category', #
-  'item', #
   'type.sortkey || 1',
-  '(last_action == "enter" || last_action == "copy") ? "Create" : "Save Changes"',
+  'typeLabelLowerPlural',
+  'typeLabelLowerSingular',
 ],
 
 'admin/flag-type/list.html.tmpl' => [
-  'type.is_active ? "active" : "inactive"', 
   'type.id', 
   'type.flag_count', 
 ],
@@ -567,13 +514,7 @@
   'target', 
 ],
 
-'account/prefs/account.html.tmpl' => [
-  'login_change_date', #
-],
-
 'account/prefs/email.html.tmpl' => [
-  'watchedusers', # Email
-  'useqacontact ? \'5\' : \'4\'', 
   'role', 
   'reason.name', 
   'reason.description',
@@ -589,9 +530,6 @@
   'tab.description', 
   'current_tab.name', 
   'current_tab.description', 
-  'current_tab.description FILTER lower',
 ],
 
 );
-
-# Should filter reports/report.html.tmpl:130 $format
